aboutsummaryrefslogtreecommitdiffstats
path: root/common/rfb/Configuration.h
diff options
context:
space:
mode:
authorAdam Tkac <atkac@redhat.com>2013-03-14 17:11:22 +0000
committerAdam Tkac <atkac@redhat.com>2013-03-14 17:11:22 +0000
commit40060b4e1a8a93ab23b0652f16504f1982e3501d (patch)
tree2732b2ad574f305944d896dd4b8ac60de1715f6d /common/rfb/Configuration.h
parent6f7f92e0434b5bfd9ede8898be2527bd4b2062c0 (diff)
downloadtigervnc-40060b4e1a8a93ab23b0652f16504f1982e3501d.tar.gz
tigervnc-40060b4e1a8a93ab23b0652f16504f1982e3501d.zip
Simplify rfb::ParameterIterator - we always iterate over all enabled params.
git-svn-id: svn://svn.code.sf.net/p/tigervnc/code/trunk@5064 3789f03b-4d11-0410-bbf8-ca57d06f2519
Diffstat (limited to 'common/rfb/Configuration.h')
-rw-r--r--common/rfb/Configuration.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/common/rfb/Configuration.h b/common/rfb/Configuration.h
index e3337f44..4feeb789 100644
--- a/common/rfb/Configuration.h
+++ b/common/rfb/Configuration.h
@@ -268,12 +268,12 @@ namespace rfb {
};
// -=- ParameterIterator
// Iterates over all the Parameters in a Configuration group. The
// current Parameter is accessed via param, the current Configuration
// via config. The next() method moves on to the next Parameter.
struct ParameterIterator {
- ParameterIterator(Configuration* c) : config(c), param(c ? c->head : 0) {}
+ ParameterIterator() : config(Configuration::global()), param(config->head) {}
void next() {
param = param->_next;
while (!param) {
@@ -268,12 +268,12 @@ namespace rfb {
};
// -=- ParameterIterator
- // Iterates over all the Parameters in a Configuration group. The
- // current Parameter is accessed via param, the current Configuration
- // via config. The next() method moves on to the next Parameter.
+ // Iterates over all enabled parameters (global + server/viewer).
+ // Current Parameter is accessed via param, the current Configuration
+ // via config. The next() method moves on to the next Parameter.
struct ParameterIterator {